summaryrefslogtreecommitdiff
path: root/t/mkinst3.sh
diff options
context:
space:
mode:
Diffstat (limited to 't/mkinst3.sh')
-rw-r--r--t/mkinst3.sh16
1 files changed, 8 insertions, 8 deletions
diff --git a/t/mkinst3.sh b/t/mkinst3.sh
index d725fdacf..71d3dfe1f 100644
--- a/t/mkinst3.sh
+++ b/t/mkinst3.sh
@@ -14,7 +14,7 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Test mkinstalldirs with spaces in directory names.
am_create_testdir=empty
. test-init.sh
@@ -26,15 +26,15 @@ mkdir '~a b' && mkdir '~a b/-x y' \
|| skip_ "directory names with spaces and metacharacters not accepted"
rm -rf '~a b'
-get_shell_script mkinstalldirs
+get_shell_script install-sh
-# Test mkinstalldirs with the installed mkdir.
+# Test with the installed mkdir.
-./mkinstalldirs '~a b/-x y'
+./install-sh -d '~a b/-x y'
test -d '~a b/-x y'
rm -rf '~a b'
# Trick mkinstalldirs into thinking mkdir does not support -p.
mkdir bin
cat >bin/mkdir <<'EOF'
@@ -55,13 +55,13 @@ chmod +x bin/mkdir
AM_PATH=$PATH; export AM_PATH
PATH=$cwd/bin$PATH_SEPARATOR$PATH; export PATH
-# Test mkinstalldirs without mkdir -p.
+# Test without mkdir -p.
-./mkinstalldirs '~a b/-x y'
+./install-sh -d '~a b/-x y'
test -d '~a b/-x y'
rm -rf '~a b'
-./mkinstalldirs "$cwd///~a b//-x y"
+./install-sh -d "$cwd///~a b//-x y"
test -d "$cwd/~a b/-x y"
rm -rf '~a b'
@@ -14,7 +14,7 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-# Test mkinstalldirs with spaces in directory names.
+# Test "install-sh -d" with spaces in directory names.
am_create_testdir=empty
. test-init.sh
@@ -26,15 +26,15 @@ mkdir '~a b' && mkdir '~a b/-x y' \
test -d '~a b/-x y'
rm -rf '~a b'
-# Trick mkinstalldirs into thinking mkdir does not support -p.
+# Trick install-sh into thinking mkdir does not support -p.
mkdir bin
cat >bin/mkdir <<'EOF'